# `royalnet.constellation`

The part of `royalnet` that handles the webserver and webpages.

It uses many features of [`starlette`](https://www.starlette.io).

## Hierarchy

- `constellation`
    - `star`
        - `shoot`